[virt-tools-list] [PATCH 2/2] tests: move the storage pool under /dev.

Giuseppe Scrivano gscrivano at gnu.org
Fri Jul 26 02:06:28 UTC 2013


The commit efab27afbf02743a3a2582e9a111eb1b7d985b26 in libvirt uses
/dev/%s for logical pools, change the tests to accommodate it.
---
 tests/cli-test-xml/clone-disk-managed.xml          |  2 +-
 tests/cli-test-xml/compare/clone-auto1.xml         | 10 ++++-----
 tests/cli-test-xml/compare/clone-auto2.xml         |  2 +-
 tests/cli-test-xml/compare/many-devices.xml        |  4 ++--
 tests/clitest.py                                   | 18 ++++++++--------
 tests/clone-xml/cross-pool-in.xml                  |  4 ++--
 tests/clone-xml/cross-pool-out.xml                 |  4 ++--
 tests/clone-xml/empty-disks-out.xml                |  2 +-
 tests/clone-xml/force-out.xml                      |  2 +-
 tests/clone-xml/general-cfg-out.xml                |  2 +-
 tests/clone-xml/managed-storage-in.xml             |  4 ++--
 tests/clone-xml/managed-storage-out.xml            |  4 ++--
 tests/clone-xml/readonly-disks-out.xml             |  2 +-
 tests/clone-xml/skip-out.xml                       |  2 +-
 tests/clonetest.py                                 | 24 +++++++++++-----------
 tests/storage-xml/pool-logical-volclone.xml        |  4 ++--
 tests/testdriver.xml                               | 20 +++++++++---------
 tests/utils.py                                     |  4 ++--
 tests/xmlconfig-xml/boot-many-devices.xml          |  2 +-
 tests/xmlconfig-xml/install-f11-ac97.xml           |  2 +-
 tests/xmlconfig-xml/install-f11-noac97.xml         |  2 +-
 tests/xmlconfig-xml/install-f11-qemu.xml           |  2 +-
 tests/xmlconfig-xml/install-f11-rheldefaults.xml   |  2 +-
 tests/xmlconfig-xml/install-f11-xen.xml            |  2 +-
 tests/xmlconfig-xml/install-f11.xml                |  2 +-
 tests/xmlconfig-xml/misc-qemu-driver-overwrite.xml |  2 +-
 tests/xmlconfig-xml/misc-qemu-iso-disk.xml         |  2 +-
 tests/xmlconfig-xml/rhel6-kvm-stage1.xml           |  4 ++--
 tests/xmlconfig-xml/rhel6-kvm-stage2.xml           |  4 ++--
 tests/xmlconfig-xml/winxp-kvm-stage1.xml           |  2 +-
 tests/xmlconfig-xml/winxp-kvm-stage2.xml           |  2 +-
 tests/xmlconfig-xml/winxp-kvm-stage3.xml           |  2 +-
 tests/xmlconfig.py                                 | 18 ++++++++--------
 tests/xmlparse-xml/add-devices-in.xml              |  2 +-
 tests/xmlparse-xml/add-devices-out.xml             |  2 +-
 tests/xmlparse-xml/change-disk-out.xml             |  2 +-
 tests/xmlparse-xml/change-guest-in.xml             |  2 +-
 tests/xmlparse-xml/change-guest-out.xml            |  2 +-
 tests/xmlparse-xml/change-media-out.xml            | 10 ++++-----
 tests/xmlparse-xml/change-smartcard-in.xml         |  2 +-
 tests/xmlparse-xml/change-smartcard-out.xml        |  2 +-
 tests/xmlparse-xml/change-tpm-in.xml               |  2 +-
 tests/xmlparse-xml/change-tpm-out.xml              |  2 +-
 tests/xmlparse.py                                  | 14 ++++++-------
 virtinst/cli.py                                    |  3 ++-
 45 files changed, 105 insertions(+), 104 deletions(-)

diff --git a/tests/cli-test-xml/clone-disk-managed.xml b/tests/cli-test-xml/clone-disk-managed.xml
index 2018111..8fe1fe2 100644
--- a/tests/cli-test-xml/clone-disk-managed.xml
+++ b/tests/cli-test-xml/clone-disk-managed.xml
@@ -15,7 +15,7 @@
   <devices>
     <disk type='file' device='disk'>
       <target dev='hda' bus='ide'/>
-      <source file='/default-pool/default-vol'/>
+      <source file='/dev/default-pool/default-vol'/>
     </disk>
     <disk type='file' device='floppy'>
       <target dev='fda' bus='fdc'/>
diff --git a/tests/cli-test-xml/compare/clone-auto1.xml b/tests/cli-test-xml/compare/clone-auto1.xml
index 1c90162..9fbc120 100644
--- a/tests/cli-test-xml/compare/clone-auto1.xml
+++ b/tests/cli-test-xml/compare/clone-auto1.xml
@@ -21,12 +21,12 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="block" device="floppy">
       <driver type="vmdk"/>
-      <source dev="/disk-pool/diskvol1-clone"/>
+      <source dev="/dev/disk-pool/diskvol1-clone"/>
       <target dev="fda" bus="fdc"/>
       <address type="drive" controller="0" bus="0" target="0" unit="0"/>
     </disk>
     <disk type="block" device="disk">
-      <source dev="/disk-pool/diskvol2"/>
+      <source dev="/dev/disk-pool/diskvol2"/>
       <target dev="sda" bus="scsi"/>
       <readonly/>
       <address type="drive" controller="0" bus="0" target="0" unit="0"/>
@@ -38,19 +38,19 @@
     </disk>
     <disk type="block" device="disk">
       <driver type="qcow2"/>
-      <source dev="/default-pool/collidevol1.img"/>
+      <source dev="/dev/default-pool/collidevol1.img"/>
       <target dev="sdc" bus="scsi"/>
       <readonly/>
       <shareable/>
       <address type="drive" controller="0" bus="0" target="0" unit="2"/>
     </disk>
     <disk type="file" device="disk">
-      <source file="/default-pool/default-vol-clone"/>
+      <source file="/dev/default-pool/default-vol-clone"/>
       <target dev="hda" bus="ide"/>
       <address type="drive" controller="0" bus="0" target="0" unit="0"/>
     </disk>
     <disk type="file" device="disk">
-      <source file="/default-pool/testvol2-clone.img"/>
+      <source file="/dev/default-pool/testvol2-clone.img"/>
       <target dev="hdb" bus="ide"/>
       <address type="drive" controller="0" bus="0" target="0" unit="1"/>
     </disk>
diff --git a/tests/cli-test-xml/compare/clone-auto2.xml b/tests/cli-test-xml/compare/clone-auto2.xml
index 0fe424d..5504cee 100644
--- a/tests/cli-test-xml/compare/clone-auto2.xml
+++ b/tests/cli-test-xml/compare/clone-auto2.xml
@@ -20,7 +20,7 @@
   <devices>
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
-      <source file="/default-pool/newvm.img"/>
+      <source file="/dev/default-pool/newvm.img"/>
       <target dev="hda" bus="ide"/>
       <address type="drive" controller="0" bus="0" target="0" unit="0"/>
     </disk>
diff --git a/tests/cli-test-xml/compare/many-devices.xml b/tests/cli-test-xml/compare/many-devices.xml
index 2dccb2a..390c22e 100644
--- a/tests/cli-test-xml/compare/many-devices.xml
+++ b/tests/cli-test-xml/compare/many-devices.xml
@@ -26,7 +26,7 @@
     <emulator>/usr/bin/test-hv</emulator>
     <disk type="file" device="disk">
       <driver cache="writeback" io="threads"/>
-      <source file="/default-pool/UPPER"/>
+      <source file="/dev/default-pool/UPPER"/>
       <target dev="hda" bus="ide"/>
       <shareable/>
       <serial>WD-WMAP9A966149</serial>
@@ -114,7 +114,7 @@
     <emulator>/usr/bin/test-hv</emulator>
     <disk type="file" device="disk">
       <driver cache="writeback" io="threads"/>
-      <source file="/default-pool/UPPER"/>
+      <source file="/dev/default-pool/UPPER"/>
       <target dev="hda" bus="ide"/>
       <shareable/>
       <serial>WD-WMAP9A966149</serial>
diff --git a/tests/clitest.py b/tests/clitest.py
index 7dbbc92..b29bb54 100644
--- a/tests/clitest.py
+++ b/tests/clitest.py
@@ -113,14 +113,14 @@ test_files = {
     'VOL'               : "testvol1.img",
     'DIR'               : os.getcwd(),
     'TREEDIR'           : treedir,
-    'MANAGEDEXIST1'     : "/default-pool/testvol1.img",
-    'MANAGEDEXIST2'     : "/default-pool/testvol2.img",
-    'MANAGEDEXISTUPPER' : "/default-pool/UPPER",
-    'MANAGEDNEW1'       : "/default-pool/clonevol",
-    'MANAGEDNEW2'       : "/default-pool/clonevol",
-    'MANAGEDDISKNEW1'   : "/disk-pool/newvol1.img",
-    'COLLIDE'           : "/default-pool/collidevol1.img",
-    'SHARE'             : "/default-pool/sharevol.img",
+    'MANAGEDEXIST1'     : "/dev/default-pool/testvol1.img",
+    'MANAGEDEXIST2'     : "/dev/default-pool/testvol2.img",
+    'MANAGEDEXISTUPPER' : "/dev/default-pool/UPPER",
+    'MANAGEDNEW1'       : "/dev/default-pool/clonevol",
+    'MANAGEDNEW2'       : "/dev/default-pool/clonevol",
+    'MANAGEDDISKNEW1'   : "/dev/disk-pool/newvol1.img",
+    'COLLIDE'           : "/dev/default-pool/collidevol1.img",
+    'SHARE'             : "/dev/default-pool/sharevol.img",
 
     'VIRTCONV_OUT'      : "%s/test.out" % virtconv_out,
     'VC_IMG1'           : "%s/virtimage/test1.virt-image" % vcdir,
@@ -750,7 +750,7 @@ vclon.add_valid("misc", "-o test --auto-clone")  # Auto flag, no storage
 vclon.add_valid("misc", "--original-xml %(CLONE_DISK_XML)s --auto-clone")  # Auto flag w/ storage,
 vclon.add_valid("misc", "--original-xml %(CLONE_STORAGE_XML)s --auto-clone")  # Auto flag w/ managed storage,
 vclon.add_valid("misc", "-o test-for-clone --auto-clone --clone-running")  # Auto flag, actual VM, skip state check
-vclon.add_valid("misc", "-o test-clone-simple -n newvm --preserve-data --file /default-pool/default-vol --clone-running --force")  # Preserve data shouldn't complain about existing volume
+vclon.add_valid("misc", "-o test-clone-simple -n newvm --preserve-data --file /dev/default-pool/default-vol --clone-running --force")  # Preserve data shouldn't complain about existing volume
 vclon.add_invalid("misc", "--auto-clone# Auto flag, actual VM, without state skip ")  # Just the auto flag
 vclon.add_invalid("misc", "-o test-for-clone --auto-clone")
 
diff --git a/tests/clone-xml/cross-pool-in.xml b/tests/clone-xml/cross-pool-in.xml
index f6f0063..6177a6f 100644
--- a/tests/clone-xml/cross-pool-in.xml
+++ b/tests/clone-xml/cross-pool-in.xml
@@ -18,11 +18,11 @@
   <devices>
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type='file' device='disk'>
-      <source file='/default-pool/testvol1.img'/>
+      <source file='/dev/default-pool/testvol1.img'/>
       <target dev='hda' bus='ide'/>
     </disk>
     <disk type='file' device='disk'>
-      <source file='/default-pool/testvol2.img'/>
+      <source file='/dev/default-pool/testvol2.img'/>
       <target dev='hdb' bus='ide'/>
     </disk>
     <interface type='network'>
diff --git a/tests/clone-xml/cross-pool-out.xml b/tests/clone-xml/cross-pool-out.xml
index 4fac96b..4200dce 100644
--- a/tests/clone-xml/cross-pool-out.xml
+++ b/tests/clone-xml/cross-pool-out.xml
@@ -18,11 +18,11 @@
   <devices>
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="file" device="disk">
-      <source file="/cross-pool/new1.img"/>
+      <source file="/dev/cross-pool/new1.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="file" device="disk">
-      <source file="/cross-pool/new2.img"/>
+      <source file="/dev/cross-pool/new2.img"/>
       <target dev="hdb" bus="ide"/>
     </disk>
     <interface type="network">
diff --git a/tests/clone-xml/empty-disks-out.xml b/tests/clone-xml/empty-disks-out.xml
index 546a930..318f08d 100644
--- a/tests/clone-xml/empty-disks-out.xml
+++ b/tests/clone-xml/empty-disks-out.xml
@@ -19,7 +19,7 @@
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="block" device="disk">
       <target dev="hda" bus="ide"/>
-      <source dev="/disk-pool/disk-vol1"/>
+      <source dev="/dev/disk-pool/disk-vol1"/>
     </disk>
     <disk type="file" device="floppy">
       <target dev="fdb" bus="fdc"/>
diff --git a/tests/clone-xml/force-out.xml b/tests/clone-xml/force-out.xml
index 0375f39..4a041a2 100644
--- a/tests/clone-xml/force-out.xml
+++ b/tests/clone-xml/force-out.xml
@@ -18,7 +18,7 @@
   <devices>
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="file" device="disk">
-      <source file="/default-pool/1234.img"/>
+      <source file="/dev/default-pool/1234.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="floppy">
diff --git a/tests/clone-xml/general-cfg-out.xml b/tests/clone-xml/general-cfg-out.xml
index 361ca74..05a1773 100644
--- a/tests/clone-xml/general-cfg-out.xml
+++ b/tests/clone-xml/general-cfg-out.xml
@@ -19,7 +19,7 @@
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="block" device="disk">
       <target dev="hda" bus="ide"/>
-      <source dev="/disk-pool/disk-vol1"/>
+      <source dev="/dev/disk-pool/disk-vol1"/>
     </disk>
     <disk type="file" device="disk">
       <target dev="hdb" bus="ide"/>
diff --git a/tests/clone-xml/managed-storage-in.xml b/tests/clone-xml/managed-storage-in.xml
index 616a8d8..8cac51e 100644
--- a/tests/clone-xml/managed-storage-in.xml
+++ b/tests/clone-xml/managed-storage-in.xml
@@ -19,11 +19,11 @@
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type='file' device='disk'>
       <driver name="qemu" type="vmdk"/>
-      <source file='/default-pool/testvol1.img'/>
+      <source file='/dev/default-pool/testvol1.img'/>
       <target dev='hda' bus='ide'/>
     </disk>
     <disk type='block' device='disk'>
-      <source dev='/disk-pool/diskvol1'/>
+      <source dev='/dev/disk-pool/diskvol1'/>
       <target dev='hdb' bus='ide'/>
     </disk>
     <interface type='network'>
diff --git a/tests/clone-xml/managed-storage-out.xml b/tests/clone-xml/managed-storage-out.xml
index 3f172cb..540f8d7 100644
--- a/tests/clone-xml/managed-storage-out.xml
+++ b/tests/clone-xml/managed-storage-out.xml
@@ -19,11 +19,11 @@
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="vmdk"/>
-      <source file="/default-pool/new1.img"/>
+      <source file="/dev/default-pool/new1.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="disk">
-      <source dev="/disk-pool/new2.img"/>
+      <source dev="/dev/disk-pool/new2.img"/>
       <target dev="hdb" bus="ide"/>
     </disk>
     <interface type="network">
diff --git a/tests/clone-xml/readonly-disks-out.xml b/tests/clone-xml/readonly-disks-out.xml
index 93933fe..83e1b38 100644
--- a/tests/clone-xml/readonly-disks-out.xml
+++ b/tests/clone-xml/readonly-disks-out.xml
@@ -19,7 +19,7 @@
     <emulator>/usr/bin/qemu-kvm</emulator>
     <disk type="block" device="disk">
       <target dev="hda" bus="ide"/>
-      <source dev="/disk-pool/disk-vol1"/>
+      <source dev="/dev/disk-pool/disk-vol1"/>
     </disk>
     <disk type="file" device="disk">
       <source file="/tmp/virtinst-test1.img"/>
diff --git a/tests/clone-xml/skip-out.xml b/tests/clone-xml/skip-out.xml
index baa41e4..01ba3e6 100644
--- a/tests/clone-xml/skip-out.xml
+++ b/tests/clone-xml/skip-out.xml
@@ -29,7 +29,7 @@
       <readonly/>
     </disk>
     <disk type="file" device="disk">
-      <source file="/default-pool/1234.img"/>
+      <source file="/dev/default-pool/1234.img"/>
       <target dev="sdb" bus="scsi"/>
     </disk>
     <interface type="network">
diff --git a/tests/storage-xml/pool-logical-volclone.xml b/tests/storage-xml/pool-logical-volclone.xml
index ef53c6c..5e6b4ff 100644
--- a/tests/storage-xml/pool-logical-volclone.xml
+++ b/tests/storage-xml/pool-logical-volclone.xml
@@ -1,13 +1,13 @@
 <?xml version="1.0"?>
 <volume>
   <name>pool-logical-volclone</name>
-  <key>/some/target/path/pool-logical-vol</key>
+  <key>/dev/pool-logical/pool-logical-vol</key>
   <source>
   </source>
   <capacity unit="bytes">10737418240</capacity>
   <allocation unit="bytes">10737418240</allocation>
   <target>
-    <path>/some/target/path/pool-logical-vol</path>
+    <path>/dev/pool-logical/pool-logical-vol</path>
     <permissions>
       <mode>0700</mode>
       <owner>10736</owner>
diff --git a/tests/testdriver.xml b/tests/testdriver.xml
index b956727..911a1e8 100644
--- a/tests/testdriver.xml
+++ b/tests/testdriver.xml
@@ -323,7 +323,7 @@
   <devices>
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type='file' device='disk'>
-      <source file='/default-pool/default-vol'/>
+      <source file='/dev/default-pool/default-vol'/>
       <target dev='hda' bus='ide'/>
     </disk>
     <interface type='network'>
@@ -367,7 +367,7 @@
   <devices>
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type='file' device='disk'>
-      <source file='/default-pool/test-clone-simple.img'/>
+      <source file='/dev/default-pool/test-clone-simple.img'/>
       <target dev='hda' bus='ide'/>
     </disk>
     <interface type='user'>
@@ -401,12 +401,12 @@
   <devices>
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type='block' device='floppy'>
-      <source dev='/disk-pool/diskvol1'/>
+      <source dev='/dev/disk-pool/diskvol1'/>
       <target dev='fda' bus='fdc'/>
       <driver type="vmdk"/>
     </disk>
     <disk type='block' device='disk'>
-      <source dev='/disk-pool/diskvol2'/>
+      <source dev='/dev/disk-pool/diskvol2'/>
       <target dev='sda' bus='scsi'/>
       <readonly/>
     </disk>
@@ -414,18 +414,18 @@
       <target dev='sdb' bus='scsi'/>
     </disk>
     <disk type='block' device='disk'>
-      <source dev='/default-pool/collidevol1.img'/>
+      <source dev='/dev/default-pool/collidevol1.img'/>
       <target dev='sdc' bus='scsi'/>
       <driver type="qcow2"/>
       <readonly/>
       <shareable/>
     </disk>
     <disk type='file' device='disk'>
-      <source file='/default-pool/default-vol'/>
+      <source file='/dev/default-pool/default-vol'/>
       <target dev='hda' bus='ide'/>
     </disk>
     <disk type='file' device='disk'>
-      <source file='/default-pool/testvol2.img'/>
+      <source file='/dev/default-pool/testvol2.img'/>
       <target dev='hdb' bus='ide'/>
     </disk>
     <interface type='network'>
@@ -757,7 +757,7 @@
   <source>
   </source>
   <target>
-    <path>/default-pool</path>
+    <path>/dev/default-pool</path>
     <permissions>
       <mode>0700</mode>
       <owner>10736</owner>
@@ -955,7 +955,7 @@
   <source>
   </source>
   <target>
-    <path>/cross-pool</path>
+    <path>/dev/cross-pool</path>
     <permissions>
       <mode>0700</mode>
       <owner>10736</owner>
@@ -1074,7 +1074,7 @@
   <source>
   </source>
   <target>
-    <path>/disk-pool</path>
+    <path>/dev/disk-pool</path>
     <permissions>
       <mode>0700</mode>
       <owner>10736</owner>
diff --git a/tests/utils.py b/tests/utils.py
index c2746ae..df52c9a 100644
--- a/tests/utils.py
+++ b/tests/utils.py
@@ -224,7 +224,7 @@ def make_import_installer():
     return virtinst.ImportInstaller(_conn)
 
 
-def make_distro_installer(location="/default-pool/default-vol"):
+def make_distro_installer(location="/dev/default-pool/default-vol"):
     inst = virtinst.DistroInstaller(_conn)
     inst.location = location
     return inst
@@ -255,7 +255,7 @@ def build_win_kvm(path=None, fake=True):
 
 def get_floppy(path=None):
     if not path:
-        path = "/default-pool/testvol1.img"
+        path = "/dev/default-pool/testvol1.img"
     d = VirtualDisk(_conn)
     d.path = path
     d.device = d.DEVICE_FLOPPY
diff --git a/tests/xmlconfig-xml/boot-many-devices.xml b/tests/xmlconfig-xml/boot-many-devices.xml
index 6249bb1..c1150df 100644
--- a/tests/xmlconfig-xml/boot-many-devices.xml
+++ b/tests/xmlconfig-xml/boot-many-devices.xml
@@ -37,7 +37,7 @@
     </disk>
     <disk type="file" device="disk">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="sdb" bus="scsi"/>
       <address type="spapr-vio"/>
     </disk>
diff --git a/tests/xmlconfig-xml/install-f11-ac97.xml b/tests/xmlconfig-xml/install-f11-ac97.xml
index 2c4d7f6..d8430bf 100644
--- a/tests/xmlconfig-xml/install-f11-ac97.xml
+++ b/tests/xmlconfig-xml/install-f11-ac97.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/install-f11-noac97.xml b/tests/xmlconfig-xml/install-f11-noac97.xml
index 6384802..4e2ea55 100644
--- a/tests/xmlconfig-xml/install-f11-noac97.xml
+++ b/tests/xmlconfig-xml/install-f11-noac97.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/install-f11-qemu.xml b/tests/xmlconfig-xml/install-f11-qemu.xml
index 3fd6197..e33f01b 100644
--- a/tests/xmlconfig-xml/install-f11-qemu.xml
+++ b/tests/xmlconfig-xml/install-f11-qemu.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/install-f11-rheldefaults.xml b/tests/xmlconfig-xml/install-f11-rheldefaults.xml
index 666eebc..829f313 100644
--- a/tests/xmlconfig-xml/install-f11-rheldefaults.xml
+++ b/tests/xmlconfig-xml/install-f11-rheldefaults.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2" cache="none"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/install-f11-xen.xml b/tests/xmlconfig-xml/install-f11-xen.xml
index 93f0818..a7552f7 100644
--- a/tests/xmlconfig-xml/install-f11-xen.xml
+++ b/tests/xmlconfig-xml/install-f11-xen.xml
@@ -20,7 +20,7 @@
   <devices>
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/install-f11.xml b/tests/xmlconfig-xml/install-f11.xml
index b5719fa..47754a2 100644
--- a/tests/xmlconfig-xml/install-f11.xml
+++ b/tests/xmlconfig-xml/install-f11.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlconfig-xml/misc-qemu-driver-overwrite.xml b/tests/xmlconfig-xml/misc-qemu-driver-overwrite.xml
index 8727379..0851a9d 100644
--- a/tests/xmlconfig-xml/misc-qemu-driver-overwrite.xml
+++ b/tests/xmlconfig-xml/misc-qemu-driver-overwrite.xml
@@ -22,7 +22,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/iso-vol"/>
+      <source file="/dev/default-pool/iso-vol"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="cdrom">
diff --git a/tests/xmlconfig-xml/misc-qemu-iso-disk.xml b/tests/xmlconfig-xml/misc-qemu-iso-disk.xml
index 6e44c2b..1e0eaa7 100644
--- a/tests/xmlconfig-xml/misc-qemu-iso-disk.xml
+++ b/tests/xmlconfig-xml/misc-qemu-iso-disk.xml
@@ -22,7 +22,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/iso-vol"/>
+      <source file="/dev/default-pool/iso-vol"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="cdrom">
diff --git a/tests/xmlconfig-xml/rhel6-kvm-stage1.xml b/tests/xmlconfig-xml/rhel6-kvm-stage1.xml
index f3a49b7..60a4ecb 100644
--- a/tests/xmlconfig-xml/rhel6-kvm-stage1.xml
+++ b/tests/xmlconfig-xml/rhel6-kvm-stage1.xml
@@ -22,12 +22,12 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/rhel6.img"/>
+      <source file="/dev/default-pool/rhel6.img"/>
       <target dev="vda" bus="virtio"/>
     </disk>
     <disk type="block" device="disk">
diff --git a/tests/xmlconfig-xml/rhel6-kvm-stage2.xml b/tests/xmlconfig-xml/rhel6-kvm-stage2.xml
index 94c40dd..a831d3e 100644
--- a/tests/xmlconfig-xml/rhel6-kvm-stage2.xml
+++ b/tests/xmlconfig-xml/rhel6-kvm-stage2.xml
@@ -20,12 +20,12 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/rhel6.img"/>
+      <source file="/dev/default-pool/rhel6.img"/>
       <target dev="vda" bus="virtio"/>
     </disk>
     <disk type="block" device="disk">
diff --git a/tests/xmlconfig-xml/winxp-kvm-stage1.xml b/tests/xmlconfig-xml/winxp-kvm-stage1.xml
index e76aa98..68d1a10 100644
--- a/tests/xmlconfig-xml/winxp-kvm-stage1.xml
+++ b/tests/xmlconfig-xml/winxp-kvm-stage1.xml
@@ -21,7 +21,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/winxp.img"/>
+      <source file="/dev/default-pool/winxp.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="disk">
diff --git a/tests/xmlconfig-xml/winxp-kvm-stage2.xml b/tests/xmlconfig-xml/winxp-kvm-stage2.xml
index 6f56501..7f54ce8 100644
--- a/tests/xmlconfig-xml/winxp-kvm-stage2.xml
+++ b/tests/xmlconfig-xml/winxp-kvm-stage2.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/winxp.img"/>
+      <source file="/dev/default-pool/winxp.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="disk">
diff --git a/tests/xmlconfig-xml/winxp-kvm-stage3.xml b/tests/xmlconfig-xml/winxp-kvm-stage3.xml
index ec57c10..09e828b 100644
--- a/tests/xmlconfig-xml/winxp-kvm-stage3.xml
+++ b/tests/xmlconfig-xml/winxp-kvm-stage3.xml
@@ -20,7 +20,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="disk">
       <driver name="qemu" type="raw"/>
-      <source file="/default-pool/winxp.img"/>
+      <source file="/dev/default-pool/winxp.img"/>
       <target dev="hda" bus="ide"/>
     </disk>
     <disk type="block" device="disk">
diff --git a/tests/xmlconfig.py b/tests/xmlconfig.py
index 74a6292..b4c2797 100644
--- a/tests/xmlconfig.py
+++ b/tests/xmlconfig.py
@@ -372,11 +372,11 @@ class TestXMLConfig(unittest.TestCase):
         self._compare(g, "misc-qemu-driver-type", True)
 
         g = utils.get_basic_fullyvirt_guest()
-        g.add_device(utils.get_filedisk("/default-pool/iso-vol"))
+        g.add_device(utils.get_filedisk("/dev/default-pool/iso-vol"))
         self._compare(g, "misc-qemu-iso-disk", True)
 
         g = utils.get_basic_fullyvirt_guest()
-        g.add_device(utils.get_filedisk("/default-pool/iso-vol"))
+        g.add_device(utils.get_filedisk("/dev/default-pool/iso-vol"))
         g.get_devices("disk")[0].driver_type = "qcow2"
         self._compare(g, "misc-qemu-driver-overwrite", True)
 
@@ -483,17 +483,17 @@ class TestXMLConfig(unittest.TestCase):
 
     def testInstallWindowsKVM(self):
         utils.set_conn(_plainkvm)
-        g = utils.build_win_kvm("/default-pool/winxp.img")
+        g = utils.build_win_kvm("/dev/default-pool/winxp.img")
         self._compare(g, "winxp-kvm-stage1", True)
 
     def testContinueWindowsKVM(self):
         utils.set_conn(_plainkvm)
-        g = utils.build_win_kvm("/default-pool/winxp.img")
+        g = utils.build_win_kvm("/dev/default-pool/winxp.img")
         self._compare(g, "winxp-kvm-stage2", True, True)
 
     def testBootWindowsKVM(self):
         utils.set_conn(_plainkvm)
-        g = utils.build_win_kvm("/default-pool/winxp.img")
+        g = utils.build_win_kvm("/dev/default-pool/winxp.img")
         self._compare(g, "winxp-kvm-stage3", False)
 
 
@@ -737,7 +737,7 @@ class TestXMLConfig(unittest.TestCase):
         g.add_device(d)
 
         d = VirtualDisk(g.conn)
-        d.path = "/default-pool/testvol1.img"
+        d.path = "/dev/default-pool/testvol1.img"
         d.bus = "scsi"
         d.driver_name = "qemu"
         d.address.type = "spapr-vio"
@@ -921,7 +921,7 @@ class TestXMLConfig(unittest.TestCase):
                                   location="tests/cli-test-xml/fakerhel6tree")
         g = utils.get_basic_fullyvirt_guest("kvm", installer=i)
         g.add_device(utils.get_floppy())
-        g.add_device(utils.get_filedisk("/default-pool/rhel6.img", fake=False))
+        g.add_device(utils.get_filedisk("/dev/default-pool/rhel6.img", fake=False))
         g.add_device(utils.get_blkdisk())
         g.add_device(utils.get_virtual_network())
         g.add_device(VirtualAudio(g.conn))
@@ -932,7 +932,7 @@ class TestXMLConfig(unittest.TestCase):
 
     def testFullKVMWinxp(self):
         utils.set_conn(_plainkvm)
-        g = utils.build_win_kvm("/default-pool/winxp.img", fake=False)
+        g = utils.build_win_kvm("/dev/default-pool/winxp.img", fake=False)
         self._testInstall(g, "winxp-kvm-stage1",
                           "winxp-kvm-stage3", "winxp-kvm-stage2")
 
@@ -1019,7 +1019,7 @@ class TestXMLConfig(unittest.TestCase):
     def testManyVirtio(self):
         d = VirtualDisk(utils.get_conn())
         d.bus = "virtio"
-        d.path = "/default-pool/testvol1.img"
+        d.path = "/dev/default-pool/testvol1.img"
 
         targetlist = []
         for ignore in range(0, (26 * 2) + 1):
diff --git a/tests/xmlparse-xml/add-devices-in.xml b/tests/xmlparse-xml/add-devices-in.xml
index e733c75..9e225f0 100644
--- a/tests/xmlparse-xml/add-devices-in.xml
+++ b/tests/xmlparse-xml/add-devices-in.xml
@@ -19,7 +19,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse-xml/add-devices-out.xml b/tests/xmlparse-xml/add-devices-out.xml
index 24d48bc..6c3b7dd 100644
--- a/tests/xmlparse-xml/add-devices-out.xml
+++ b/tests/xmlparse-xml/add-devices-out.xml
@@ -19,7 +19,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse-xml/change-disk-out.xml b/tests/xmlparse-xml/change-disk-out.xml
index 6702201..135715f 100644
--- a/tests/xmlparse-xml/change-disk-out.xml
+++ b/tests/xmlparse-xml/change-disk-out.xml
@@ -51,7 +51,7 @@
         <total_bytes_sec>6</total_bytes_sec>
       </iotune>
       <driver cache="writeback" io="native"/>
-      <source file="/default-pool/default-vol"/>
+      <source file="/dev/default-pool/default-vol"/>
       <shareable/>
     </disk>
     <disk type="block" device="floppy">
diff --git a/tests/xmlparse-xml/change-guest-in.xml b/tests/xmlparse-xml/change-guest-in.xml
index b6ab49c..ab56c03 100644
--- a/tests/xmlparse-xml/change-guest-in.xml
+++ b/tests/xmlparse-xml/change-guest-in.xml
@@ -29,7 +29,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse-xml/change-guest-out.xml b/tests/xmlparse-xml/change-guest-out.xml
index eb3dd42..ca350b1 100644
--- a/tests/xmlparse-xml/change-guest-out.xml
+++ b/tests/xmlparse-xml/change-guest-out.xml
@@ -31,7 +31,7 @@
     <emulator>/usr/binnnn/fooemu</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse-xml/change-media-out.xml b/tests/xmlparse-xml/change-media-out.xml
index 878fc22..3849d6b 100644
--- a/tests/xmlparse-xml/change-media-out.xml
+++ b/tests/xmlparse-xml/change-media-out.xml
@@ -13,27 +13,27 @@
     <disk type="file" device="cdrom">
       <target dev="hda" bus="ide"/>
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/default-vol"/>
+      <source file="/dev/default-pool/default-vol"/>
     </disk>
     <disk type="block" device="cdrom">
       <target dev="hdb" bus="ide"/>
       <driver name="qemu" type="raw"/>
-      <source dev="/disk-pool/diskvol1"/>
+      <source dev="/dev/disk-pool/diskvol1"/>
     </disk>
     <disk type="block" device="cdrom">
       <target dev="hdc" bus="ide"/>
       <driver name="qemu" type="raw"/>
-      <source dev="/disk-pool/diskvol1"/>
+      <source dev="/dev/disk-pool/diskvol1"/>
     </disk>
     <disk type="file" device="floppy">
       <target dev="fda" bus="fdc"/>
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/default-vol"/>
+      <source file="/dev/default-pool/default-vol"/>
     </disk>
     <disk type="block" device="floppy">
       <target dev="fdb" bus="fdc"/>
       <driver name="qemu" type="raw"/>
-      <source dev="/disk-pool/diskvol1"/>
+      <source dev="/dev/disk-pool/diskvol1"/>
     </disk>
   </devices>
 </domain>
diff --git a/tests/xmlparse-xml/change-smartcard-in.xml b/tests/xmlparse-xml/change-smartcard-in.xml
index 944f03e..5033e8e 100644
--- a/tests/xmlparse-xml/change-smartcard-in.xml
+++ b/tests/xmlparse-xml/change-smartcard-in.xml
@@ -26,7 +26,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type='file' device='floppy'>
       <driver name='qemu' type='qcow2'/>
-      <source file='/default-pool/testvol1.img'/>
+      <source file='/dev/default-pool/testvol1.img'/>
       <target dev='fda' bus='fdc'/>
     </disk>
     <disk type='file' device='disk'>
diff --git a/tests/xmlparse-xml/change-smartcard-out.xml b/tests/xmlparse-xml/change-smartcard-out.xml
index 91b9d4f..72305af 100644
--- a/tests/xmlparse-xml/change-smartcard-out.xml
+++ b/tests/xmlparse-xml/change-smartcard-out.xml
@@ -26,7 +26,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse-xml/change-tpm-in.xml b/tests/xmlparse-xml/change-tpm-in.xml
index 24aa998..271dc95 100644
--- a/tests/xmlparse-xml/change-tpm-in.xml
+++ b/tests/xmlparse-xml/change-tpm-in.xml
@@ -26,7 +26,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type='file' device='floppy'>
       <driver name='qemu' type='qcow2'/>
-      <source file='/default-pool/testvol1.img'/>
+      <source file='/dev/default-pool/testvol1.img'/>
       <target dev='fda' bus='fdc'/>
     </disk>
     <disk type='file' device='disk'>
diff --git a/tests/xmlparse-xml/change-tpm-out.xml b/tests/xmlparse-xml/change-tpm-out.xml
index b97a95a..a606d48 100644
--- a/tests/xmlparse-xml/change-tpm-out.xml
+++ b/tests/xmlparse-xml/change-tpm-out.xml
@@ -26,7 +26,7 @@
     <emulator>/usr/lib/xen/bin/qemu-dm</emulator>
     <disk type="file" device="floppy">
       <driver name="qemu" type="qcow2"/>
-      <source file="/default-pool/testvol1.img"/>
+      <source file="/dev/default-pool/testvol1.img"/>
       <target dev="fda" bus="fdc"/>
     </disk>
     <disk type="file" device="disk">
diff --git a/tests/xmlparse.py b/tests/xmlparse.py
index 5381d92..00eae62 100644
--- a/tests/xmlparse.py
+++ b/tests/xmlparse.py
@@ -281,7 +281,7 @@ class XMLParseTest(unittest.TestCase):
         check("error_policy", "stop", None)
 
         check = self._make_checker(disk6)
-        check("path", None, "/default-pool/default-vol")
+        check("path", None, "/dev/default-pool/default-vol")
         disk6.sync_path_props()
         check("shareable", False, True)
         check("driver_cache", None, "writeback")
@@ -760,28 +760,28 @@ class XMLParseTest(unittest.TestCase):
 
         disk = guest.get_devices("disk")[0]
         check = self._make_checker(disk)
-        check("path", None, "/default-pool/default-vol")
+        check("path", None, "/dev/default-pool/default-vol")
         disk.sync_path_props()
 
         disk = guest.get_devices("disk")[1]
         check = self._make_checker(disk)
-        check("path", None, "/default-pool/default-vol")
-        check("path", "/default-pool/default-vol", "/disk-pool/diskvol1")
+        check("path", None, "/dev/default-pool/default-vol")
+        check("path", "/dev/default-pool/default-vol", "/dev/disk-pool/diskvol1")
         disk.sync_path_props()
 
         disk = guest.get_devices("disk")[2]
         check = self._make_checker(disk)
-        check("path", None, "/disk-pool/diskvol1")
+        check("path", None, "/dev/disk-pool/diskvol1")
         disk.sync_path_props()
 
         disk = guest.get_devices("disk")[3]
         check = self._make_checker(disk)
-        check("path", None, "/default-pool/default-vol")
+        check("path", None, "/dev/default-pool/default-vol")
         disk.sync_path_props()
 
         disk = guest.get_devices("disk")[4]
         check = self._make_checker(disk)
-        check("path", None, "/disk-pool/diskvol1")
+        check("path", None, "/dev/disk-pool/diskvol1")
         disk.sync_path_props()
 
         self._alter_compare(guest.get_xml_config(), outfile)
diff --git a/virtinst/cli.py b/virtinst/cli.py
index 7af3ac3..a027614 100644
--- a/virtinst/cli.py
+++ b/virtinst/cli.py
@@ -1428,7 +1428,8 @@ def _parse_disk_source(guest, path, pool, vol, size, fmt, sparse):
             raise ValueError(_("Storage volume must be specified as "
                                "vol=poolname/volname"))
         vollist = vol.split("/")
-        voltuple = (vollist[0], vollist[1])
+        voltuple = (vollist[-2], vollist[-1])
+
         logging.debug("Parsed volume: as pool='%s' vol='%s'",
                       voltuple[0], voltuple[1])
         if voltuple[0] == DEFAULT_POOL_NAME:
diff --git a/tests/clonetest.py b/tests/clonetest.py
index 1137065..bd8ddb2 100644
--- a/tests/clonetest.py
+++ b/tests/clonetest.py
@@ -28,14 +28,14 @@ CLONE_NAME = "clone-new"
 # Create some files to use as test images
 FILE1 = "/tmp/virtinst-test1.img"
 FILE2 = "/tmp/virtinst-test2.img"
-P1_VOL1  = "/default-pool/testvol1.img"
-P1_VOL2  = "/default-pool/testvol2.img"
-P2_VOL1  = "/cross-pool/testvol1.img"
-P2_VOL2  = "/cross-pool/testvol2.img"
+P1_VOL1  = "/dev/default-pool/testvol1.img"
+P1_VOL2  = "/dev/default-pool/testvol2.img"
+P2_VOL1  = "/dev/cross-pool/testvol1.img"
+P2_VOL2  = "/dev/cross-pool/testvol2.img"
 
-POOL1 = "/default-pool"
-POOL2 = "/cross-pool"
-DISKPOOL = "/disk-pool"
+POOL1 = "/dev/default-pool"
+POOL2 = "/dev/cross-pool"
+DISKPOOL = "/dev/disk-pool"
 
 local_files = [FILE1, FILE2]
 
@@ -92,7 +92,7 @@ class TestClone(unittest.TestCase):
         cloneobj.clone_macs = ["22:23:45:67:89:00", "22:23:45:67:89:01"]
 
         if disks is None:
-            disks = ["/disk-pool/disk-vol1", "/tmp/clone2.img",
+            disks = ["/dev/disk-pool/disk-vol1", "/tmp/clone2.img",
                      "/tmp/clone3.img", "/tmp/clone4.img",
                      "/tmp/clone5.img", None]
 
@@ -179,14 +179,14 @@ class TestClone(unittest.TestCase):
     def testCloneStorageForce(self):
         base = "force"
         self._clone_helper(base,
-                           disks=["/default-pool/1234.img",
+                           disks=["/dev/default-pool/1234.img",
                                   None, "/tmp/clone2.img"],
                            force_list=["hda", "fdb", "sdb"])
 
     def testCloneStorageSkip(self):
         base = "skip"
         self._clone_helper(base,
-                           disks=["/default-pool/1234.img",
+                           disks=["/dev/default-pool/1234.img",
                                   None, "/tmp/clone2.img"],
                            skip_list=["hda", "fdb"])
 
@@ -203,9 +203,9 @@ class TestClone(unittest.TestCase):
     def testCloneManagedToUnmanaged(self):
         base = "managed-storage"
 
         # We are trying to clone from a pool (/default-pool) to unmanaged
         # storage. For this case, the cloning needs to fail back to manual
         # operation (no libvirt calls), but since /default-pool doesn't exist,
         # this should fail.
         try:
             self._clone_helper(base, ["/tmp/new1.img", "/tmp/new2.img"],
@@ -203,9 +203,9 @@ class TestClone(unittest.TestCase):
         base = "managed-storage"
 
-        # We are trying to clone from a pool (/default-pool) to unmanaged
+        # We are trying to clone from a pool (/dev/default-pool) to unmanaged
         # storage. For this case, the cloning needs to fail back to manual
@@ -203,9 +203,9 @@ class TestClone(unittest.TestCase):
         # storage. For this case, the cloning needs to fail back to manual
-        # operation (no libvirt calls), but since /default-pool doesn't exist,
+        # operation (no libvirt calls), but since /dev/default-pool doesn't exist,
         # this should fail.
         try:
-- 
1.8.3.1




More information about the virt-tools-list mailing list